@@ -1,12 +1,15 @@
 package Rubric::Entry;
 
+use strict;
+use warnings;
+
 =head1 NAME
 
 Rubric::Entry - a single entry made by a user
 
 =head1 VERSION
 
- $Id: Entry.pm,v 1.20 2005/01/20 20:58:59 rjbs Exp $
+ $Id: /my/rjbs/code/rubric/trunk/lib/Rubric/Entry.pm 2680 2005-08-20T18:14:28.122231Z rjbs  $
 
 =head1 DESCRIPTION
 
@@ -16,6 +19,7 @@ Rubric::DBI, which is a Class::DBI class.
 =cut
 
 use base qw(Rubric::DBI);
+use Encode qw(_utf8_on);
 use Time::Piece;
 
 __PACKAGE__->table('entries');
@@ -47,6 +51,12 @@ The link attribute returns a Rubric::Link.
 
 __PACKAGE__->has_a(link => 'Rubric::Link');
 
+=head2 uri
+
+The uri attribute returns the URI of the entry's link.
+
+=cut
+
 sub uri { my ($self) = @_; return unless $self->link; $self->link->uri; }
 
 =head2 user
@@ -78,8 +88,8 @@ pair for tags used on the week's 50 most recent entries.
 __PACKAGE__->set_sql(recent_tags_counted => <<'');
 SELECT tag, COUNT(*) as count
 FROM   entrytags
-WHERE
-	entry IN (SELECT id FROM entries WHERE created > ? LIMIT 100)
+WHERE entry IN (SELECT id FROM entries WHERE created > ? LIMIT 100)
+  AND tag NOT LIKE '@%%'
 GROUP BY tag
 ORDER BY count DESC
 LIMIT 50
@@ -106,26 +116,27 @@ inflated to Time::Piece objects.
 __PACKAGE__->has_a(
 	$_ => 'Time::Piece',
 	deflate => 'epoch',
-	inflate => sub { gmtime($_[0]) }
+	inflate => Rubric::Config->display_localtime ? sub { localtime($_[0]) }
+	                                             : sub { gmtime($_[0]) }
 ) for qw(created modified);
 
-__PACKAGE__->add_trigger(before_create => \&default_title);
+__PACKAGE__->add_trigger(before_create => \&_default_title);
 
-__PACKAGE__->add_trigger(before_create => \&create_times);
-__PACKAGE__->add_trigger(before_update => \&update_times);
+__PACKAGE__->add_trigger(before_create => \&_create_times);
+__PACKAGE__->add_trigger(before_update => \&_update_times);
 
-sub default_title {
+sub _default_title {
 	my $self = shift;
 	$self->title('(default)') unless $self->{title}
 }
 
-sub create_times {
+sub _create_times {
 	my $self = shift;
-	$self->created(scalar gmtime) unless $self->{created};
-	$self->modified(scalar gmtime) unless $self->{modified};
+	$self->created(scalar gmtime) unless defined $self->{created};
+	$self->modified(scalar gmtime) unless defined $self->{modified};
 }
 
-sub update_times {
+sub _update_times {
 	my $self = shift;
 	$self->modified(scalar gmtime);
 }
@@ -153,12 +164,12 @@ the result of running it.  (Either a list or an Iterator is returned.)
 =cut
 
 sub query {
-	my ($self, $arg) = @_;
+	my $self = shift;
 	require Rubric::Entry::Query;
-	Rubric::Entry::Query->query($arg);
+	Rubric::Entry::Query->query(@_);
 }
 
-=head2 set_new_tags(\@tags)
+=head2 set_new_tags(\%tags)
 
 This method replaces all entry's current tags with the new set of tags.
 
@@ -169,23 +180,39 @@ sub set_new_tags {
 	$self->entrytags->delete_all;
 	$self->update;
 
-	$self->add_to_tags({ tag => $_ }) for @$tags;
+  while (my ($tag, $value) = each %$tags) {
+    $self->add_to_tags({ tag => $tag, tag_value => $value });
+  }
 }
 
 =head2 tags_from_string($taglist)
 
 This (class) method takes a string of tags, delimited by whitespace, and
-returns a reference to an array of the tags, dropping invalid tags.
+returns an array of the tags, dropping invalid tags.
 
 Valid tags (shouldn't this be documented somewhere else instead?) may contain
-letters, numbers, underscores, colons, dots, and asterisks.
+letters, numbers, underscores, colons, dots, and asterisks.  Hyphens me be
+used, but not as the first character.
 
 =cut
 
 sub tags_from_string {
-	my ($class, $taglist) = @_;
-	$taglist =~ /^([\s\w\d:.*]+)$/; $taglist = $1;
-	[ grep /^[\w\d:.*]+$/, split /\s+/, $taglist ];
+	my ($class, $tagstring) = @_;
+	my %seen;
+
+	_utf8_on($tagstring);
+
+	my %tags = $tagstring ? map { (index($_, ':') > 0) ? split(/:/, $_, 2) : ($_ => undef) }
+	                        split /(?:\+|\s)+/, $tagstring
+	                      : ();
+
+	die "invalid characters in tagstring" 
+		if grep { defined $_ and $_ !~ /\A[@\w\d:.*][-\w\d:.*]*\Z/ } keys %tags;
+
+	die "invalid characters in tagstring" 
+		if grep { defined $_ and $_ !~ /\A[-\w\d:.*]*\Z/ } values %tags;
+
+	return \%tags;
 }
 
 ## return retrieve_all'd objects in recent-to-older order
