@@ -6,7 +6,7 @@ Rubric::Link - a link (URI) against which entries have been made
 
 =head1 VERSION
 
- $Id: Link.pm,v 1.5 2005/01/23 20:00:24 rjbs Exp $
+ $Id: /my/rjbs/code/rubric/trunk/lib/Rubric/Link.pm 2680 2005-08-20T18:14:28.122231Z rjbs  $
 
 =head1 DESCRIPTION
 
@@ -31,6 +31,15 @@ __PACKAGE__->table('links');
 
 __PACKAGE__->columns(All => qw(id uri md5));
 
+__PACKAGE__->add_constraint('scheme', uri => \&_check_schema);
+sub _check_schema {
+	my ($uri) = @_;
+	return 1 unless $uri;
+	return 1 unless Rubric::Config->allowed_schemes;
+	$uri = URI->new($uri) unless ref $uri;
+	return scalar grep { $_ eq $uri->scheme } @{ Rubric::Config->allowed_schemes }
+}
+
 =head1 RELATIONSHIPS
 
 =head2 entries
@@ -49,7 +58,7 @@ This method returns the number of entries that refer to this link.
 =cut
 
 __PACKAGE__->set_sql(
-	entry_count => "SELECT COUNT(*) FROM entries WHERE id = ?"
+	entry_count => "SELECT COUNT(*) FROM entries WHERE link = ?"
 );
 
 sub entry_count {
